@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
-
 import ast
 import inspect
-import os.path
 import re
 
+from pathlib import Path
+
 from docutils import nodes
 from docutils.parsers.rst import Directive
 from pygments.lexer import RegexLexer, bygroups
@@ -102,7 +101,7 @@ def markdown_2_rst(lines):
             code = not code
             space = " " * (len(line.rstrip()) - 3)
             if code:
-                out.append("\n\n%s.. code-block:: none\n\n" % space)
+                out.append(f"\n\n{space}.. code-block:: none\n\n")
             else:
                 out.append("\n")
         else:
@@ -141,10 +140,10 @@ def screenshots(screenshots_data, module_name):
 
     out = []
     for shot in file_sort(shots):
-        if not os.path.exists("../doc/screenshots/%s.png" % shot):
+        if not Path(f"../doc/screenshots/{shot}.png").exists():
             continue
-        out.append(u"\n.. image:: screenshots/{}.png\n\n".format(shot))
-    return u"".join(out)
+        out.append(f"\n.. image:: screenshots/{shot}.png\n\n")
+    return "".join(out)
 
 
 def create_module_docs():
@@ -155,7 +154,7 @@ def create_module_docs():
     # get screenshot data
     screenshots_data = {}
     samples = get_samples()
-    for sample in samples.keys():
+    for sample in samples:
         module = sample.split("-")[0]
         if module not in screenshots_data:
             screenshots_data[module] = []
@@ -163,8 +162,8 @@ def create_module_docs():
 
     out = []
     # details
-    for module in sorted(data.keys()):
-        out.append("\n.. _module_%s:\n" % module)  # reference for linking
+    for module in sorted(data):
+        out.append(f"\n.. _module_{module}:\n")  # reference for linking
         out.append(
             "\n{name}\n{underline}\n\n{screenshots}{details}\n".format(
                 name=module,
@@ -174,8 +173,7 @@ def create_module_docs():
             )
         )
     # write include file
-    with open("../doc/modules-info.inc", "w") as f:
-        f.write("".join(out))
+    Path("../doc/modules-info.inc").write_text("".join(out))
 
 
 def get_variable_docstrings(filename):
@@ -214,9 +212,7 @@ def get_variable_docstrings(filename):
                 key = None
         return docstrings, values
 
-    with open(filename, "r") as f:
-        source = f.read()
-    return walk_node(ast.parse(source))
+    return walk_node(ast.parse(filename.read_text()))
 
 
 def get_py3_info():
@@ -225,14 +221,14 @@ def get_py3_info():
     along with their docstrings.
     """
     # get all documented constants and their values
-    constants, values = get_variable_docstrings("../py3status/py3.py")
+    constants, values = get_variable_docstrings(Path("../py3status/py3.py"))
     # we only care about ones defined in Py3
     constants = constants["Py3"]
     # sort them alphabetically
-    constants = [(k, v) for k, v in sorted(constants.items())]
+    constants = sorted(constants.items())
 
     # filter values as we only care about values defined in Py3
-    values = dict([(v, k[4:]) for k, v in values.items() if k.startswith("Py3.")])
+    values = {v: k[4:] for k, v in values.items() if k.startswith("Py3.")}
 
     def make_value(attr, arg, default):
         """
@@ -263,11 +259,11 @@ def get_py3_info():
                 # default values set?
                 if len_args - index <= len_defaults:
                     default = defaults[len_defaults - len_args + index]
-                    sig.append("%s=%s" % (arg, make_value(attr, arg, default)))
+                    sig.append("{}={}".format(arg, make_value(attr, arg, default)))
                 else:
                     sig.append(arg)
 
-            definition = "%s(%s)" % (attr, ", ".join(sig))
+            definition = "{}({})".format(attr, ", ".join(sig))
             methods.append((definition, item.__doc__))
             continue
         try:
@@ -308,13 +304,12 @@ def create_py3_docs():
         output = []
         for name, desc in v:
             output.append("")
-            output.append(".. _%s:" % name)  # reference for linking
+            output.append(f".. _{name}:")  # reference for linking
             output.append("")
-            output.append(".. py:%s:: %s" % (trans[k], name))
+            output.append(f".. py:{trans[k]}:: {name}")
             output.append("")
             output.extend(auto_undent(desc))
-        with open("../doc/py3-%s-info.inc" % k, "w") as f:
-            f.write("\n".join(output))
+        Path(f"../doc/py3-{k}-info.inc").write_text("\n".join(output))
 
 
 def create_auto_documentation():
@@ -342,10 +337,10 @@ class ScreenshotDirective(Directive):
     def run(self):
         env = self.state.document.settings.env
 
-        targetid = "screenshot-%d" % env.new_serialno("screenshot")
+        targetid = f"screenshot-{env.new_serialno('screenshot')}"
         targetnode = nodes.target("", "", ids=[targetid])
 
-        image_name = "_%s" % targetid
+        image_name = f"_{targetid}"
         try:
             content = ast.literal_eval("\n".join(self.content))
         except:  # noqa e722
@@ -356,7 +351,7 @@ class ScreenshotDirective(Directive):
             }
 
         process(image_name, content, False)
-        image_path = os.path.join("screenshots", image_name + ".png")
+        image_path = Path("screenshots") / (image_name + ".png")
         screenshot_node = nodes.image(uri=image_path)
         return [targetnode, screenshot_node]
 
