@@ -4,16 +4,10 @@ import sys
 from threading import Thread
 from subprocess import Popen, PIPE
 from json import loads
+from shlex import quote as shell_quote
 
 from py3status.profiling import profile
 
-try:
-    # Python 3
-    from shlex import quote as shell_quote
-except ImportError:
-    # Python 2
-    from pipes import quote as shell_quote
-
 
 class IOPoller:
     """
@@ -112,7 +106,7 @@ class Events(Thread):
         index = event.get("index")
         module_info = self.py3_wrapper.output_modules.get(module_name)
         output = module_info["module"].get_latest()
-        full_text = u"".join([out["full_text"] for out in output])
+        full_text = "".join(out["full_text"] for out in output)
 
         partial = None
         if index is not None:
@@ -182,7 +176,7 @@ class Events(Thread):
             module = module_info["module"]
             module.click_event(event)
             if self.config["debug"]:
-                self.py3_wrapper.log("dispatching event {}".format(event))
+                self.py3_wrapper.log(f"dispatching event {event}")
 
             # to make the bar more responsive to users we refresh the module
             # unless the on_click event called py3.prevent_refresh()
@@ -193,7 +187,7 @@ class Events(Thread):
         if default_event:
             # default button 2 action is to clear this method's cache
             if self.config["debug"]:
-                self.py3_wrapper.log("dispatching default event {}".format(event))
+                self.py3_wrapper.log(f"dispatching default event {event}")
             self.py3_wrapper.refresh_modules(module_name)
 
         # find container that holds the module and call its onclick
@@ -208,7 +202,7 @@ class Events(Thread):
         such as setting the index needed for composits.
         """
         if self.config["debug"]:
-            self.py3_wrapper.log("received event {}".format(event))
+            self.py3_wrapper.log(f"received event {event}")
 
         # usage variables
         event["index"] = event.get("index", "")
@@ -231,12 +225,12 @@ class Events(Thread):
         if self.config["debug"]:
             self.py3_wrapper.log(
                 'trying to dispatch event to module "{}"'.format(
-                    "{} {}".format(name, instance).strip()
+                    f"{name} {instance}".strip()
                 )
             )
 
         # guess the module config name
-        module_name = "{} {}".format(name, instance).strip()
+        module_name = f"{name} {instance}".strip()
 
         default_event = False
         module_info = self.output_modules.get(module_name)
