@@ -1,6 +1,8 @@
+import time
+
+from ast import literal_eval
 from sys import argv
 from threading import Event
-from time import sleep, time
 
 from py3status.core import Common, Module
 
@@ -61,6 +63,20 @@ def module_test(module_class, config=None):
     if not config:
         config = {}
 
+    # config cli arguments
+    arguments, term = argv[1:], False
+    for index, arg in enumerate(arguments):
+        if "--term" in arg:
+            term = True
+        elif arg[0:2] == "--":
+            key = arguments[index][2:]
+            value = arguments[index + 1]
+            try:
+                value = literal_eval(value)
+            except (SyntaxError, ValueError):
+                pass
+            config[key] = value
+
     py3_config = {
         "general": {
             "color_bad": "#FF0000",
@@ -81,8 +97,8 @@ def module_test(module_class, config=None):
 
     while not m.error_messages:
         try:
-            for meth in m.methods:
-                m.methods[meth]["cached_until"] = time()
+            for my_method in m.methods.values():
+                my_method["cached_until"] = time.perf_counter()
             m.run()
             output = m.get_latest()
             for item in output:
@@ -91,7 +107,7 @@ def module_test(module_class, config=None):
                 if "name" in item:
                     del item["name"]
 
-            if "--term" in argv:
+            if term:
                 line = "\033[0m"
                 for item in output:
                     if item.get("urgent"):
@@ -109,7 +125,7 @@ def module_test(module_class, config=None):
                     output = output[0]
                 print(output)
 
-            sleep(1)
+            time.sleep(1)
         except KeyboardInterrupt:
             m.kill()
             break
