@@ -55,7 +55,8 @@ SAMPLE OUTPUT
 {'full_text': 'all:  34.4% ( 82.0 KiB/s)'}
 """
 
-from time import time
+import time
+from pathlib import Path
 
 
 class Py3status:
@@ -91,12 +92,15 @@ class Py3status:
 
         if self.init["diskstats"]:
             self.last_diskstats = self._get_diskstats(self.disk)
-            self.last_time = time()
+            self.last_time = time.perf_counter()
 
         self.thresholds_init = self.py3.get_color_names_list(self.format)
 
     def _get_df_usages(self, disk):
-        df_usages = self.py3.command_output(["df", "-k"])
+        try:
+            df_usages = self.py3.command_output(["df", "-k"])
+        except self.py3.CommandError as ce:
+            df_usages = ce.output
         total, used, free, devs = 0, 0, 0, []
 
         if disk and not disk.startswith("/dev/"):
@@ -127,7 +131,7 @@ class Py3status:
         if disk and disk.startswith("/dev/"):
             disk = disk[5:]
 
-        with open("/proc/diskstats") as fd:
+        with Path("/proc/diskstats").open() as fd:
             for line in fd:
                 data = line.split()
                 if disk:
@@ -142,7 +146,7 @@ class Py3status:
         return read, write
 
     def _calc_diskstats(self, diskstats):
-        current_time = time()
+        current_time = time.perf_counter()
         timedelta = current_time - self.last_time
         read = (diskstats[0] - self.last_diskstats[0]) / timedelta
         write = (diskstats[1] - self.last_diskstats[1]) / timedelta
