@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Group modules and switch between them.
 
@@ -87,7 +86,7 @@ cycle_again
 {'full_text': 'module 3'}
 """
 
-from time import time
+import time
 
 # maximum wait for initial content at startup
 MAX_NO_CONTENT_WAIT = 5
@@ -107,9 +106,9 @@ class Py3status:
     cycle = 0
     fixed_width = False
     format = None
-    format_button_closed = u"+"
-    format_button_open = u"-"
-    format_closed = u"{button}"
+    format_button_closed = "+"
+    format_button_open = "-"
+    format_closed = "{button}"
     open = True
 
     class Meta:
@@ -119,8 +118,9 @@ class Py3status:
         if not self.items:
             raise Exception(STRING_ERROR)
 
+        self.first_run = True
         self.active = 0
-        self.cycle_time = time() + self.cycle
+        self.cycle_time = time.perf_counter() + self.cycle
         self.cycle_timeout = self.cycle
         self.last_active = 0
         self.urgent = False
@@ -129,9 +129,9 @@ class Py3status:
         # set default format etc based on click_mode
         if self.format is None:
             if self.click_mode == "button":
-                self.format = u"{output} {button}"
+                self.format = "{output} {button}"
             else:
-                self.format = u"{output}"
+                self.format = "{output}"
         # if no button then force open
         if not self.py3.format_contains(self.format, "button"):
             self.open = True
@@ -146,7 +146,7 @@ class Py3status:
         # ensure that active is valid
         self.active = self.active % len(self.items)
 
-        return set([self.items[self.active]])
+        return {self.items[self.active]}
 
     def _urgent_function(self, module_list):
         """
@@ -165,12 +165,12 @@ class Py3status:
         # and then pad with spaces to make correct width.
         current = []
         widths = []
-        for i in range(len(self.items)):
-            output = self.py3.get_output(self.items[i])
+        for i, item in enumerate(self.items):
+            output = self.py3.get_output(item)
             if not output:
                 widths.append(0)
             else:
-                widths.append(sum([len(x["full_text"]) for x in output]))
+                widths.append(sum(len(x["full_text"]) for x in output))
             if i == self.active:
                 current = output
                 current_width = widths[-1]
@@ -188,45 +188,52 @@ class Py3status:
         return current
 
     def _change_active(self, delta):
-        # we want to ignore any empty outputs
-        # to prevent endless cycling we limit ourselves to only going through
-        # the outputs once.
+        # we want to skip empty outputs. to prevent endless cycling,
+        # we limit ourselves to only going through the outputs once.
         self.active = (self.active + delta) % len(self.items)
         if not self._get_output() and self.last_active != self.active:
             self._change_active(delta)
         self.last_active = self.active
 
-    def group(self):
-        update_time = None
-        self.cycle = 0
-
+    def _get_output_and_time(self):
         # get an output. again if empty (twice).
-        for x in range(3):
+        for _ in range(3):
             output = self._get_output()
             if output:
+                update_time = None
                 break
-            self._change_active(1)
+            elif not self.first_run:
+                self._change_active(1)
         else:
             update_time = MAX_NO_CONTENT_WAIT
 
+        return output, update_time
+
+    def group(self):
+        output, update_time = self._get_output_and_time()
+
         # check for urgents
         urgent = output and output[0].get("urgent")
         self.urgent_history[self.active] = urgent
         mod_urgent = any(self.urgent_history.values())
 
         # keep cycling if defined and no urgent
-        if self.cycle_timeout and not urgent:
-            self.cycle = self.cycle_timeout
-            if time() >= self.cycle_time:
+        self.cycle = 0
+        if self.first_run:
+            self.first_run = False
+            update_time = 1
+        elif self.cycle_timeout and not urgent:
+            current_time = time.perf_counter()
+            if current_time >= self.cycle_time - 0.1:
                 self._change_active(1)
-                self.cycle_time = time() + self.cycle
+                output, update_time = self._get_output_and_time()
+                self.cycle = self.cycle_timeout
+                self.cycle_time = current_time + self.cycle
+            else:
+                self.cycle = self.cycle_time - current_time
 
         # time
-        update_time = update_time or self.cycle or None
-        if update_time is not None:
-            cached_until = self.py3.time_in(self.cycle)
-        else:
-            cached_until = self.py3.CACHE_FOREVER
+        cached_until = update_time or self.cycle or self.py3.CACHE_FOREVER
 
         if self.open:
             format_control = self.format_button_open
@@ -239,7 +246,7 @@ class Py3status:
 
         button = {"full_text": format_control, "index": "button"}
         response = {
-            "cached_until": cached_until,
+            "cached_until": self.py3.time_in(cached_until),
             "full_text": self.py3.safe_format(
                 current_format,
                 {
@@ -269,7 +276,7 @@ class Py3status:
                 return
 
         self.cycle = self.cycle_timeout
-        self.cycle_time = time() + self.cycle
+        self.cycle_time = time.perf_counter() + self.cycle
 
         if button == self.button_next:
             if self.open:
