@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Support i3blocks blocklets in py3status.
 
@@ -198,8 +197,6 @@ class Py3status:
                 fcntl.fcntl(fd, fcntl.F_SETFL, fl)
                 if process.poll():
                     break
-                if self.py3.is_python_2():
-                    line = line.decode("utf-8")
                 self.persistent_output = line
                 self.py3.update()
                 if line[-1] == "\n":
@@ -214,11 +211,9 @@ class Py3status:
                 for line in iter(process.stdout.readline, b""):
                     if process.poll():
                         break
-                    if self.py3.is_python_2():
-                        line = line.decode("utf-8")
                     self.persistent_output = line
                     self.py3.update()
-        self.py3.log("command exited {cmd}".format(cmd=command))
+        self.py3.log(f"command exited {command}")
         self.persistent_output = "Error\nError\n{}".format(
             self.py3.COLOR_ERROR or self.py3.COLOR_BAD
         )
@@ -246,9 +241,6 @@ class Py3status:
                 raise Exception(msg.format(cmd=command, error=e))
 
             _output, _error = process.communicate()
-            if self.py3.is_python_2():
-                _output = _output.decode("utf-8")
-                _error = _error.decode("utf-8")
             retcode = process.poll()
 
             # return code of 33 means urgent
@@ -327,11 +319,11 @@ class Py3status:
 
         # blocklet label gets prepended
         if self.label:
-            block_response["full_text"] = u"{}{}".format(
+            block_response["full_text"] = "{}{}".format(
                 self.label, block_response["full_text"]
             )
             if "short_text" in block_response:
-                block_response["short_text"] = u"{}{}".format(
+                block_response["short_text"] = "{}{}".format(
                     self.label, block_response["short_text"]
                 )
 
