@@ -96,7 +96,7 @@ SAMPLE OUTPUT
 """
 
 from datetime import timedelta
-from time import time
+import time
 from gi.repository import GObject
 from gi.repository.GLib import GError
 from threading import Thread
@@ -117,14 +117,11 @@ STOPPED = 2
 
 
 def _get_time_str(microseconds):
-    seconds = int(microseconds / 1000000)
-    time = str(timedelta(seconds=seconds))
-    if time[0] == "0":
-        time = time[2:]
-        if time[0] == "0":
-            time = time[1:]
-
-    return time
+    delta = timedelta(seconds=microseconds // 1_000_000)
+    delta_str = str(delta).lstrip("0").lstrip(":")
+    if delta_str.startswith("0"):
+        delta_str = delta_str[1:]
+    return delta_str
 
 
 class BrokenDBusMpris:
@@ -162,9 +159,6 @@ class BrokenDBusMpris:
                         self._parent.PlaybackStatus = msg["PlaybackStatus"]
                     if "Metadata" in msg:
                         self._parent.Metadata = msg["Metadata"]
-                        self._parent.Metadata["xesam:artist"] = ", ".join(
-                            msg["Metadata"]["xesam:artist"]
-                        )
 
                 except KeyError:
                     pass
@@ -321,7 +315,7 @@ class Py3status:
             and self._data.get("state") == PLAYING
         ):
             # Don't get trapped in aliasing errors!
-            update = time() + 0.5
+            update = time.perf_counter() + 0.5
         else:
             update = self.py3.CACHE_FOREVER
 
@@ -348,9 +342,7 @@ class Py3status:
     def _get_response_buttons(self):
         response = {}
 
-        for button in self._control_states.keys():
-            control_state = self._control_states[button]
-
+        for button, control_state in self._control_states.items():
             if self._get_button_state(control_state):
                 color = self.py3.COLOR_CONTROL_ACTIVE or self.py3.COLOR_GOOD
             else:
@@ -454,12 +446,14 @@ class Py3status:
         if not player_id.startswith(SERVICE_BUS):
             return False
 
-        # Fixes chromium mpris
+        # Fixes chromium/google-chrome mpris
         try:
             player = self._dbus.get(player_id, SERVICE_BUS_URL)
         except KeyError:
             if "chromium" in player_id:
                 player = BrokenDBusMpris(self._dbus, "Chromium", "Stopped")
+            elif "chrome" in player_id:
+                player = BrokenDBusMpris(self._dbus, "Chrome", "Stopped")
             else:
                 return False
 
@@ -500,7 +494,7 @@ class Py3status:
             "index": index,
             "identity": identity,
             "name": name,
-            "full_name": "{} {}".format(name, index),
+            "full_name": f"{name} {index}",
             "status": status,
             "subscription": subscription,
         }
@@ -633,7 +627,7 @@ class Py3status:
         index = event["index"]
         button = event["button"]
 
-        if index not in self._control_states.keys():
+        if index not in self._control_states:
             if button == self.button_toggle:
                 index = "toggle"
             elif button == self.button_stop:
