@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display network speed and bandwidth usage.
 
 Configuration parameters:
@@ -33,8 +32,8 @@ SAMPLE OUTPUT
 ]
 """
 
-from __future__ import division  # python2 compatibility
-from time import time
+import time
+from pathlib import Path
 
 
 class Py3status:
@@ -44,8 +43,8 @@ class Py3status:
     # available configuration parameters
     cache_timeout = 2
     format = (
-        u"{nic} [\?color=down LAN(Kb): {down}↓ {up}↑] "
-        u"[\?color=total T(Mb): {download}↓ {upload}↑ {total}↕]"
+        r"{nic} [\?color=down LAN(Kb): {down}↓ {up}↑] "
+        r"[\?color=total T(Mb): {download}↓ {upload}↑ {total}↕]"
     )
     nic = None
     thresholds = {
@@ -110,10 +109,10 @@ class Py3status:
     def post_config_hook(self):
         self.last_transmitted_bytes = 0
         self.last_received_bytes = 0
-        self.last_time = time()
+        self.last_time = time.perf_counter()
         # Get default gateway from /proc.
         if self.nic is None:
-            with open("/proc/net/route") as fh:
+            with Path("/proc/net/route").open() as fh:
                 for line in fh:
                     fields = line.strip().split()
                     if fields[1] == "00000000" and int(fields[3], 16) & 2:
@@ -121,12 +120,12 @@ class Py3status:
                         break
             if self.nic is None:
                 self.nic = "lo"
-            self.py3.log("selected nic: %s" % self.nic)
+            self.py3.log(f"selected nic: {self.nic}")
 
         self.thresholds_init = self.py3.get_color_names_list(self.format)
 
     def _get_bytes(self):
-        with open("/proc/net/dev") as fh:
+        with Path("/proc/net/dev").open() as fh:
             net_data = fh.read().split()
         interface_index = net_data.index(self.nic + ":")
         received_bytes = int(net_data[interface_index + 1])
@@ -136,7 +135,7 @@ class Py3status:
     def netdata(self):
         received_bytes, transmitted_bytes = self._get_bytes()
         # speed
-        current_time = time()
+        current_time = time.perf_counter()
         timedelta = current_time - self.last_time
         self.last_time = current_time
         down = (received_bytes - self.last_received_bytes) / 1024 / timedelta
