@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Perform a bandwidth test with speedtest-cli.
 
 Use middle-click to start the speed test.
@@ -127,9 +126,10 @@ details
 ]
 """
 
+import time
 from json import loads
 from threading import Thread
-from time import time
+
 
 STRING_NOT_INSTALLED = "not installed"
 
@@ -141,9 +141,9 @@ class Py3status:
     # available configuration parameters
     button_share = None
     format = (
-        u"speedtest[\?if=elapsed&color=elapsed_time  "
-        u"{elapsed_time}s][ [\?color=download ↓{download}Mbps] "
-        u"[\?color=upload ↑{upload}Mbps]]"
+        r"speedtest[\?if=elapsed&color=elapsed_time  "
+        r"{elapsed_time}s][ [\?color=download ↓{download}Mbps] "
+        r"[\?color=upload ↑{upload}Mbps]]"
     )
     thresholds = {
         "download": [(0, "cyan")],
@@ -195,11 +195,11 @@ class Py3status:
         if any(x in tests for x in self.placeholders):
             for x in tests:
                 if x not in self.placeholders:
-                    self.speedtest_command += " --no-{}".format(x)
+                    self.speedtest_command += f" --no-{x}"
 
     def _set_speedtest_data(self):
         # start
-        self.start_time = time()
+        self.start_time = time.perf_counter()
         self.speedtest_data["elapsed"] = True
 
         try:
@@ -218,12 +218,12 @@ class Py3status:
 
         # end
         self.speedtest_data["elapsed"] = False
-        self.speedtest_data["elapsed_time"] = time() - self.start_time
+        self.speedtest_data["elapsed_time"] = time.perf_counter() - self.start_time
 
     def speedtest(self):
         if self.speedtest_data.get("elapsed"):
             cached_until = 0
-            self.speedtest_data["elapsed_time"] = time() - self.start_time
+            self.speedtest_data["elapsed_time"] = time.perf_counter() - self.start_time
         else:
             cached_until = self.py3.CACHE_FOREVER
             self.py3.storage_set("speedtest_data", self.speedtest_data)
@@ -243,7 +243,7 @@ class Py3status:
         if button == self.button_share:
             share = self.speedtest_data.get("share")
             if share:
-                self.py3.command_run("xdg-open {}".format(share))
+                self.py3.command_run(f"xdg-open {share}")
         if button == self.button_refresh:
             if self.thread and not self.thread.isAlive():
                 self.thread = None
