@@ -92,7 +92,7 @@ SAMPLE OUTPUT
 """
 
 from importlib import import_module
-from os.path import expanduser
+from pathlib import Path
 
 
 class Py3status:
@@ -116,7 +116,7 @@ class Py3status:
                 if not self.py3.format_contains(self.format, config_name):
                     continue
             if not getattr(self, config_name, None):
-                raise Exception("missing %s" % config_name)
+                raise Exception(f"missing {config_name}")
 
         self.connect = getattr(import_module(self.database), "connect")
         self.operational_error = getattr(
@@ -124,7 +124,7 @@ class Py3status:
         )
         self.is_parameters_a_dict = isinstance(self.parameters, dict)
         if not self.is_parameters_a_dict:
-            self.parameters = expanduser(self.parameters)
+            self.parameters = Path(self.parameters).expanduser()
 
         self.thresholds_init = {}
         for name in ("format", "format_row"):
