@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display tasks currently running in taskwarrior.
 
@@ -51,16 +50,13 @@ class Py3status:
             raise Exception(STRING_NOT_INSTALLED)
         self.placeholders = self.py3.get_placeholders_list(self.format)
         if self.filter:
-            self.taskwarrior_command = "task %s export" % self.filter
+            self.taskwarrior_command = f"task {self.filter} export"
         else:
             self.taskwarrior_command = "task export"
 
     @staticmethod
     def descriptions(tasks_json):
-        def _describeTask(taskObj):
-            return str(taskObj["id"]) + " " + taskObj["description"]
-
-        return ", ".join(map(_describeTask, tasks_json))
+        return ", ".join(f"{t['id']} {t['description']}" for t in tasks_json)
 
     @staticmethod
     def tasks(tasks_json):
