@@ -118,12 +118,12 @@ class Py3status:
                     self.device = last_device
                     break
         else:
-            device = " `{}`".format(self.device) if self.device else ""
+            device = f" `{self.device}`" if self.device else ""
             raise Exception(STRING_NO_DEVICE + device)
 
         self._max_bitrate = 0
         self._ssid = ""
-        self.color_down = getattr(self.py3, "COLOR_{}".format(self.down_color.upper()))
+        self.color_down = getattr(self.py3, f"COLOR_{self.down_color.upper()}")
         self.commands = set()
         self.ip_addr_list_id = ["ip", "addr", "list", self.device]
         self.iw_dev_id_link = [iw, "dev", self.device, "link"]
@@ -148,13 +148,13 @@ class Py3status:
             self.py3.log(msg)
 
     def _dbm_to_percent(self, dbm):
-        return 2.0 * (dbm + 100)
+        return 2 * (dbm + 100)
 
     def _percent_to_dbm(self, percent):
-        return (percent / 2.0) - 100
+        return (percent / 2) - 100
 
     def _get_wifi_data(self, command):
-        for time in range(2):
+        for _ in range(2):
             try:
                 return self.py3.command_output(command)
             except self.py3.CommandError as ce:
@@ -209,7 +209,7 @@ class Py3status:
         freq_out = re.search(r"freq: ([\-0-9]+)", iw)
         if freq_out:
             freq_mhz = int(freq_out.group(1))
-            freq_ghz = freq_mhz / 1000.0
+            freq_ghz = freq_mhz / 1000
 
         # ip
         if self.py3.format_contains(self.format, "ip"):
@@ -229,7 +229,7 @@ class Py3status:
 
         # wifi
         if ssid is not None:
-            icon = self.blocks[int(math.ceil(quality / 100.0 * (len(self.blocks) - 1)))]
+            icon = self.blocks[math.ceil(quality / 100 * (len(self.blocks) - 1))]
             color = self.py3.COLOR_GOOD
             if bitrate:
                 if bitrate <= self.bitrate_bad:
